-- loadram_in8 - 16-Bit-RAM 1 KWorte, Eingang 8 Bit, 2KBytes mit Auto-Increment-Zhler
-- Wert wird mit incr_pulse geschrieben und dann mit fallender Flanke interner Adresszhler um 1 erhht
--
-- LSB first, Little Endian wie Atmel AVR, d.h. Bytefolge 55h, AAh wird zu Ausgangswert AA55h
-- Carsten Meyer 02/2009
--
-- Standard IEEE libraries
--
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;
--
-- The Unisim Library is used to define Xilinx primitives. It is also used during
-- simulation. The source can be viewed at %XILINX%\vhdl\src\unisims\unisim_VCOMP.vhd
--  
library unisim;
use unisim.vcomponents.all;
--
--
entity loadram_in8 is
    Port (	addr : in std_logic_vector(9 downto 0);
				dataout : out std_logic_vector(15 downto 0);
				sysclk : in std_logic;
				datain: in std_logic_vector(7 downto 0);
				reset : in std_logic;
				incr_pulse : in std_logic
				); 
    end loadram_in8;

architecture behave of loadram_in8 is
--  <-----Cut code below this line and paste into the architecture body---->

   -- RAMB16_S18_S18: Virtex-II/II-Pro, Spartan-3/3E 1k x 16 + 2 Parity bits Dual-Port RAM
   -- Xilinx HDL Language Template, version 10.1.2
	signal addr_count : std_logic_vector ( 10 downto 0 );	

begin
--
  --Instantiate the Xilinx primitive for a block RAM
   RAMB16_S9_S18_inst : RAMB16_S9_S18
   generic map (
      INIT_A => X"000", --  Value of output RAM registers on Port A at startup
      INIT_B => X"00000", --  Value of output RAM registers on Port B at startup
      SRVAL_A => X"000", --  Port A ouput value upon SSR assertion
      SRVAL_B => X"00000", --  Port B ouput value upon SSR assertion
      WRITE_MODE_A => "WRITE_FIRST", --  WRITE_FIRST, READ_FIRST or NO_CHANGE
      WRITE_MODE_B => "WRITE_FIRST", --  WRITE_FIRST, READ_FIRST or NO_CHANGE
      SIM_COLLISION_CHECK => "ALL") -- "NONE", "WARNING", "GENERATE_X_ONLY", "ALL" 
      -- keine INITs, RAM vorerst leer
   port map (

      DOA => open,      -- Port A 8-bit Data Output
      DOB => dataout(15 downto 0),      -- Port B 16-bit Data Output
      DOPA => open,    -- Port A 1-bit Parity Output
      DOPB => open,    -- Port B 2-bit Parity Output
      ADDRA => addr_count,  -- Port A 11-bit Address Input
      ADDRB => addr,  -- Port B 10-bit Address Input
      CLKA => incr_pulse,    -- Port B Clock
      CLKB => sysclk,    -- Port B Clock
      DIA => datain(7 downto 0),      -- Port A 16-bit Data Input
      DIB => "0000000000000000",      -- Port B 16-bit Data Input
      DIPA => "0",    -- Port A 1-bit parity Input
      DIPB => "00",    -- Port B 2-bit parity Input
      ENA => '1',      -- Port A RAM Enable Input
      ENB => '1',      -- PortB RAM Enable Input
      SSRA => '0',    -- Port A Synchronous Set/Reset Input
      SSRB => '0',    -- Port B Synchronous Set/Reset Input
      WEA => '1',       -- Port A Write Enable Input
      WEB => '0'      -- Port B Write Enable Input
   );
	
	addr_counter : process ( incr_pulse, reset )
	-- Adresszhler fr Auto-Increment
	begin
   if reset = '1' then
      addr_count <= (others =>'0');
   elsif (incr_pulse'event and incr_pulse = '0') then
      addr_count<= addr_count+1;
   end if;
	end process;
	
	
end behave;
